@@ -24,6 +24,18 @@ def _re(variable, re):
 DURATION = re.compile(_re('hours', 'h|hrs?|hours?') + _re('minutes', 'm|mins?') + _re('seconds', 's|sec?'))
 
 
+def is_num(x):
+    return isinstance(x, (int, float, complex)) and not isinstance(x, bool)
+
+def duration(t):
+    if isinstance(t, datetime.timedelta):
+        return t
+    if is_num(t):
+        return datetime.timedelta(seconds=t)
+    if isinstance(t, str):
+        return parse_duration(t)
+    return None
+
 def parse_duration(time_str):
     # print(time_str)
     parsed = DURATION.match(time_str.strip())
