@@ -7,7 +7,7 @@ import traceback
 from asyncio.locks import BoundedSemaphore
 
 from lemmings.task_set_run import TaskSetRun
-from lemmings.utils import _num, duration2sec
+from lemmings.utils import _num, duration2sec, exception_with_line
 from lemmings.utils.colors import Color
 from lemmings.utils.const import DONE, FAIL
 
@@ -69,33 +69,31 @@ class Worker:
         except BaseException as e:
             if not task.system:
                 self.stat.fail()
-            print_stat(FAIL, comment=str(e), failed=True)
+            print_stat(FAIL, comment=exception_with_line(e), failed=True)
             if self.debug:
-                print(e)
-                traceback.print_stack(file=sys.stdout)
+                traceback.print_exception(*sys.exc_info(), file=sys.stdout)
+                traceback.print_exc()
 
     def execute(self):
         Color.enable(self.ansi_colors)
         loop = asyncio.get_event_loop()
-        offset = datetime.timedelta(0)
+        # offset = datetime.timedelta(0)
         scheduled_tasks = []
 
-        def schedule(task):
-            nonlocal offset
+        def schedule(task, offset=datetime.timedelta(0)):
             future = asyncio.ensure_future(self.run_task(offset, task))
             scheduled_tasks.append(future)
             if not task.system:
                 self.stat.schedule()
-                offset += self.task_set.sleep_time
 
         self.task_run = TaskSetRun(self, self.task_set)
         self.semaphore = self._semaphore()
 
+        self.log("scheduling tasks")
         # setup
-        schedule(self.task_run.setup_task())
-
-        for task in self.task_run:
-            schedule(task)
+        for x in self.task_run.schedule(False):
+            offset, task = x
+            schedule(task, offset)
         self.log(f"Queue: {_num(self.stat.total)} in worker / {_num(self.stat.shared_total)} total")
         loop.run_until_complete(asyncio.wait(scheduled_tasks))
 
